/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.demo.chess;

import java.io.IOException;
import java.net.URISyntaxException;
import java.util.List;
import java.util.logging.Logger;
import net.java.html.json.ComputedProperty;
import net.java.html.json.Function;
import net.java.html.json.Model;
import net.java.html.json.Property;

/**
 *
 * @author Jaroslav Tulach <jtulach@netbeans.org>
 */
@Model(className = "UI", properties = {
    @Property(name = "status", type = String.class),
    @Property(name = "selectedGameId", type = String.class),
    @Property(name = "boards", type = Board.class, array = true),
    @Property(name = "viewGames", type = Games.class),
})
public class UIModel {
    private static final Logger LOG = Logger.getLogger(UIModel.class.getName());
    
    @ComputedProperty static boolean viewGamesActive(String selectedGameId) {
        return selectedGameId == null;
    }
    
    @ComputedProperty static Board selectedBoard(String selectedGameId, List<Board> boards) {
        Board active = null;
        for (Board b : boards) {
            b.setActive(false);
            if (selectedGameId != null && selectedGameId.equals(b.getGameId())) {
                b.setActive(true);
                active = b;
            }
        }
        return active;
    }
    
    @Function static void activateGame(UI m, Board data) {
        m.setSelectedGameId(data.getGameId());
    }

    @Function static void activateSettings(UI m) {
        m.setSelectedGameId(null);
    }
    
    private static int boardCnt;
    
    @Function static void createGame(UI u) {
        Board b = Rules.createBoard();
        b.setGameId("id" + ++boardCnt);
        final String wp = u.getViewGames().getWhitePlayer();
        b.setWhitePlayer(wp);
        final String bp = u.getViewGames().getBlackPlayer();
        b.setBlackPlayer(bp);
        b.setStatus(wp + " vs. " + bp);
        u.getBoards().add(b);
        u.setSelectedGameId(b.getGameId());
        
        u.getViewGames().setWhitePlayer(null);
        u.getViewGames().setBlackPlayer(null);
    }

    


    private static Board findBoard(UI ui, String gameId) {
        for (Board tmp : ui.getBoards()) {
            if (tmp.getGameId().equals(gameId)) {
                return tmp;
            }
        }
        return null;
    }
    
    
    @Function static void joinGame(UI u) {
    }

    @Function static void leave(UI ui, Board data) {
        ui.getBoards().remove(data);
        ui.setSelectedGameId(null);
    }
    
    public static void initialize(String... args) throws URISyntaxException, IOException {
        UI ui = new UI();
        ui.setStatus("Ready.");
        ui.applyBindings();
    }

}
